#
# spec file for package peazip
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         _peazipinstalldir %{_libdir}/peazip

Name:           peazip
Version:        10.3.0
Release:        1.2
Summary:        Graphical file archiver
License:        LGPL-3.0-only
Group:          Productivity/Archiving/Compression
URL:            https://peazip.github.io/
Source0:        https://github.com/peazip/PeaZip/releases/download/%{version}/peazip-%{version}.src.zip
Source1:        altconf.txt
# The help file did not change between 9.9.0 and 9.9.1. When it does, replace version number with the version macro again.
Source2:        https://github.com/peazip/PeaZip/releases/download/10.0.0/peazip_help.pdf
Patch0:         peazip-desktop.patch
# PATCH-FIX-OPENSUSE peazip-build_PIE.patch -- aloisio@gmx.com
Patch1:         peazip-build_PIE.patch
# PATCH-FIX-OPENSUSE peazip-help_path.patch set correct path for the pdf guide -- aloisio@gmx.com
Patch2:         peazip-help_path.patch
# PATCH-FEATURE-OPENSUSE peazip-debuginfo.patch
Patch3:         peazip-debuginfo.patch
BuildRequires:  arc
BuildRequires:  brotli
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  fpc
BuildRequires:  fpc-src
BuildRequires:  kf5-filesystem
BuildRequires:  lazarus-ide
BuildRequires:  lazarus-lcl-qt6
BuildRequires:  lazarus-tools
BuildRequires:  libX11-devel
BuildRequires:  unzip
BuildRequires:  upx
BuildRequires:  zpaq
BuildRequires:  zstd
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150100
BuildRequires:  p7zip-full
Requires:       p7zip-full
%else
BuildRequires:  p7zip
Requires:       p7zip
%endif
Requires:       upx
Suggests:       arc
Suggests:       brotli
Suggests:       zpaq
Suggests:       zstd

%description
PeaZip is a file and archive manager GUI for many formats.

Create: 7Z, ARC, BZ2, GZ, *PAQ, PEA, QUAD/BALZ, TAR, UPX, WIM, XZ, ZIP files

Extract 150+ archive types: ACE, ARJ, CAB, DMG, ISO, LHA, RAR, UDF, ZIPX and more

It can extract, create and convert multiple archives at once,
create self-extracting archives, split/join files, supports strong encryption with two-factor authentication,
has an encrypted password manager, secure deletion, can find duplicate files, calculate hashes, and
export job definition as a script.

%if 0%{?suse_version} < 1690
%package kf5
Summary:        KF5 servicemenu for peazip
Group:          Productivity/Archiving/Compression
Requires:       peazip
BuildArch:      noarch

%description kf5
PeaZip is a file and archive manager GUI for many formats.
This subpackage contains the KF5 integration.
%else

%package kf6
Summary:        KF6 servicemenu for peazip
Group:          Productivity/Archiving/Compression
Requires:       peazip
BuildArch:      noarch

%description kf6
PeaZip is a file and archive manager GUI for many formats.
This subpackage contains the KF6 integration.
%endif

%prep
%autosetup -p1 -n %{name}-%{version}.src
chmod +w res/share/lang
dos2unix readme.txt
mv res/share/copying/copying.txt .
cp %{SOURCE2} peazip_help.pdf

%build
cd dev
lazbuild --add-package metadarkstyle/metadarkstyle.lpk
# Add additional packages to vanilla Lazarus
lazbuild \
	--lazarusdir=%{_libdir}/lazarus \
%ifarch x86_64
	--cpu=x86_64 \
%endif
	--widgetset=qt6 \
  --max-process-count=1 \
	-B --add-package metadarkstyle/metadarkstyle.lpk
# Build Peazip
lazbuild \
	--lazarusdir=%{_libdir}/lazarus \
%ifarch x86_64
	--cpu=x86_64 \
%endif
	--widgetset=qt6 \
  --max-process-count=1 \
	-B project_pea.lpi project_peach.lpi

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_peazipinstalldir}
cp -r res %{buildroot}%{_peazipinstalldir}
cp %{SOURCE1} %{buildroot}%{_peazipinstalldir}/res

mkdir -p %{buildroot}%{_peazipinstalldir}/res/bin/7z
mkdir -p %{buildroot}%{_peazipinstalldir}/res/bin/upx
ln -s %{_bindir}/7z  %{buildroot}%{_peazipinstalldir}/res/bin/7z/7z
ln -s %{_bindir}/upx  %{buildroot}%{_peazipinstalldir}/res/bin/upx/upx

mkdir -p %{buildroot}%{_peazipinstalldir}/res/bin/arc
mkdir -p %{buildroot}%{_peazipinstalldir}/res/bin/brotli
mkdir -p %{buildroot}%{_peazipinstalldir}/res/bin/zpaq
mkdir -p %{buildroot}%{_peazipinstalldir}/res/bin/zstd
ln -s %{_bindir}/arc  %{buildroot}%{_peazipinstalldir}/res/bin/arc/arc
ln -s %{_bindir}/brotli  %{buildroot}%{_peazipinstalldir}/res/bin/brotli/brotli
ln -s %{_bindir}/zpaq  %{buildroot}%{_peazipinstalldir}/res/bin/zpaq/zpaq
ln -s %{_bindir}/zstd  %{buildroot}%{_peazipinstalldir}/res/bin/zstd/zstd

install -m755 dev/peazip %{buildroot}%{_peazipinstalldir}
ln -s %{_peazipinstalldir}/peazip %{buildroot}%{_bindir}/peazip
install -m755 dev/pea %{buildroot}%{_peazipinstalldir}/res
ln -s %{_peazipinstalldir}/res/pea %{buildroot}%{_bindir}/pea

mkdir -p  %{buildroot}%{_datadir}/applications/
cp %{buildroot}%{_peazipinstalldir}/res/share/batch/freedesktop_integration/peazip.desktop %{buildroot}%{_datadir}/applications/
rm %{buildroot}%{_peazipinstalldir}/res/share/batch/freedesktop_integration/peazip.desktop
# Remove duplicate comment line
sed -i '/Comment=PeaZip/d' %{buildroot}%{_datadir}/applications/peazip.desktop
# Set correct category
sed -i 's/Categories=Qt;KDE;Utility;System;Archiving;/Categories=Qt;KDE;Utility;Archiving;/' %{buildroot}%{_datadir}/applications/peazip.desktop
mkdir -p %{buildroot}%{_datadir}/pixmaps/
cp %{buildroot}%{_peazipinstalldir}/res/share/batch/freedesktop_integration/peazip.png %{buildroot}%{_datadir}/pixmaps/
rm %{buildroot}%{_peazipinstalldir}/res/share/batch/freedesktop_integration/peazip.png

chmod +x %{buildroot}%{_peazipinstalldir}/res/share/batch/freedesktop_integration/Nautilus-scripts/PeaZip/*
%if 0%{?suse_version} < 1690
pushd %{buildroot}%{_peazipinstalldir}/res/share/batch/freedesktop_integration/KDE-servicemenus/KDE5-dolphin/
mkdir -p %{buildroot}%{_kf5_servicesdir}/ServiceMenus
install -m644 *.desktop %{buildroot}%{_kf5_servicesdir}/ServiceMenus
%else
pushd %{buildroot}%{_peazipinstalldir}/res/share/batch/freedesktop_integration/KDE-servicemenus/KDE6-dolphin/
mkdir -p %{buildroot}%{_datadir}/kio/servicemenus
install -m644 *.desktop %{buildroot}%{_datadir}/kio/servicemenus/
%endif
popd
# Remove hard linked png
rm %{buildroot}%{_peazipinstalldir}/res/share/icons/peazip.png

find %{buildroot} -type f -size 0 -delete

%fdupes %{buildroot}/%{_prefix}

%files
%license copying.txt
%doc readme.txt peazip_help.pdf
%{_bindir}/pea
%{_bindir}/peazip
%{_peazipinstalldir}
%{_datadir}/applications/peazip.desktop
%{_datadir}/pixmaps/peazip.png

%if 0%{?suse_version} < 1690
%files kf5
%dir %{_kf5_servicesdir}/ServiceMenus
%{_kf5_servicesdir}/ServiceMenus/*.desktop
%else

%files kf6
%dir %{_datadir}/kio
%dir %{_datadir}/kio/servicemenus
%{_datadir}/kio/servicemenus/*.desktop
%endif

%changelog
* Fri Feb 28 2025 Paolo Stivanin <info@paolostivanin.com>
- Update to 10.3.0:
  * https://peazip.github.io/changelog.html
* Sat Jan  4 2025 Paolo Stivanin <info@paolostivanin.com>
- Update to 10.2.0:
  * enhances detection of issues in archives
  * improves displaying archive comments
  * adds support for Brotli and Zstandard maximum compression
  * updates app's icon to unify the look & feel on all platforms.
  * 7z backend is updated to 24.09
  * PEA is updated to 1.22 introducing hybrid KDF mode, employing both PBKDF2 and Scrypt to increase resiliency against dictionary and brute force password-recovery attacks.
  * Qt6 packages replace Qt5 ones, and Flatpak is now built for Wayland (with fallback X11 option).
* Tue Nov 12 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 10.1.0:
  BACKEND
  * Pea 1.21, introduced scrypt KDF as default option to improve resilience to password guessing attacks (increasing memory cost per instance) over PBKDF2 implemented in previous versions
  CODE
  * Fixed "Ask before overwriting (in console)" extraction option, now correctly sets the app in console mode superseding other options
  * Fixed directory copy/move on Unix-like systems
  FILE MANAGER
  * GUI update
  EXTRACTION and ARCHIVING
  * Updated compression pre-sets
* Mon Oct 28 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 10.0.0:
  BACKEND
  * Pea 1.20, can now search hash values of files on Google and Virustotal for detecting known malware,
    new command line switches to show text preview of files, and to directly save checksum/hash results
    in GNU Coreutils -compatible formats
  * 7z 24.08
  CODE
  * Legacy code cleanup
  * Sorted tab order of UI items
  * Various fixes
  FILE MANAGER
  * (Linux) Added MTP devices folder (Media Transfer Protocol) in Filesystem section of navigation sidebar,
    to make easier to access to mounted devices, i.e. Android phones / tablets
  * Expanded File tools section in file browser context menu, archive/extract context menu, and in Test menu in tool bar; it is now possible to
    + Save hash values in GNU Coreutils compatible format
    + Search SHA256 hash values on Google and VirusTotal
    + Display Text preview of file (attempts to parse file as utf8 text, displays linle numbers, text strings and line mumbers can be sorted alphabetically)
  * Revamped GUI
    + Hints and tooltips can now be turned on/off from Options > Settings, General tab
    + Icons used more sparingly to avoid information repetition and overload
    + Updated progress screen
    + Updated GUI rendering engine to be more flexible and memory efficient (up to 30%% depending on the icon mode)
    + Updated Style menu
    + Updated Themes and embedded icons
    + Updated context menu
  EXTRACTION and ARCHIVING
  * From Options > Settings, Advanced tab it is possible to set "7z / p7zip syntax level" back to 17.05 and 16.02 releases,
    to improve compatibility with the syntaxt of legacy 7z / p7zip versions
  * Improved quick "Extract here" link in the toolbar is now also shown when one or more archives are selected in the file browser
  * Updated compression presets
  * Added tar.gz, tar.xz, and tar.zst presets
* Mon Aug 19 2024 PragmaticLinux <info@pragmaticlinux.com>
- Update to 9.9.1:
  CODE
  * Updated GitHub repository
  FILE MANAGER
  * Fixed rename bugs which prevented detecting filenames collisions in some cases
  * Updated translations
* Mon Aug  5 2024 PragmaticLinux <info@pragmaticlinux.com>
- Update to 9.9.0:
  BACKEND
  * 7z 24.07
  * Pea 1.19 adds optional extra KDF rounds for triple cascaded encryption in .PEA format
    (up to 20 millions iterations for each algorithm, total 60 M rounds)
  * Zstd 1.5.6 (Windows, Linux)
  CODE
  * Compiled with Lazarus 3.4, sources are still compatible with Lazarus 2.x
  * Fixes and code cleanup
  * Fixed loading Custom format in custom compression settings
  * Fixed browsing some special cases of archives (containing items with absolute paths
    starting with directopry separator characters)
  * Updated Options screen
  * (7z/p7zip) syntax level can now be set to 21.07 and 23.01 legacy versions, form
    Options > Settings > Advances, Backend binaries
  * (7z/p7zip) new option to show timestamps as UTC insead of local time, form form
    Options > Settings > Archive manager
  * New group for TAR -related options in Options > Settings > Archive manager
  FILE MANAGER
  * (Windows) When UAC elevation is needed (non writeable output path) the user is now
    offered to restart the app UAC elevated.
  * In this way it is not needed to require elevation to subsequent operations on the
    same path, and it is possible to use all of functions of PeaZip (console mode,
    force interactive password)
  * Added internal drag and drop features
  * It is now possible to perform internal drag and drop extraction from file/archive
    manager to sidebar, both toward treeview panel and navigation panel (bookmarks,
    filesystem, history paths).
  * It is possible to extract either one or more entire archive(s), or selected
    archive content while browsing archives
  * If right mouse button is pressed, it will be possible to choese to extract with
    or without new folder/smart new folder, overriding defaults
  * It is now possible to use drag and drop to add items from file browser/archive
    browser to Bookmarks panel
  * Archives are now tested for encryption also for list/test operations, so password is
    required in advance if needed
  * Improved System tools menu for Linux (context menu, File manager)
  * New "Extract here" quick link on the right of the tool bar, shown when browing an archive
  * Extracts selected content, or entire archive if nothing is selected
  * Extracts to new/smart folder depending on settings, link text is adjusted accordingly
  * Shows context menu with all extraction options (here, smart, new folder) to be used
    on the fly without changing the configuration
  * The app now dispays if it isrunning as root (admin or UAC elevated on Windows),
    showing <ROOT> (or <ADMIN>) note in main menu, or dropdown main menu (if main menu is
    hidden)
  EXTRACTION and ARCHIVING
  * Improved reading DMG, IMG, RPM, and SQUASHFS files as archives
  * Revamped task launcher GUI
  * Updated compression Presets files to support latest options set
* Mon May 13 2024 PragmaticLinux <info@pragmaticlinux.com>
- Update to 9.8.0:
  BACKEND
  * Pea 1.18
  CODE
  * Code cleanup
  * Compiled with Lazarus 3.2, sources are still compatible with Lazarus 2.x line
  * Various fixes
  * Fixed directory name sorting which for some widget sets was wrongly displayed in
    treeview and breadcrumb dropdown menus
  * Fixed drag and drop extraction failing for some paths (Windows)
  * Fixed inability to browse symlinked directories on Windows (other systems are
    immune from the issue)
  FILE MANAGER
  * Added "Always browse archives in flat view" option switch in main menu > Browse and
    app's context menu > Navigation
  * Added Comment, and Info functions to Status bar context menu, to improve its
    usefulness in providing information to user
  * Improved direct extraction of archives from context menu
  * From context menu "Extract to" submenu it is now possible to directly extract all
    or selected item(s), without further confirmation, to any output path in bookmarks,
    history or breadcrumb
  * Extract here links (optionally to smart folder or to new folder) can now extract
    all or selected items
  * In the dropdown menu of Extract button are still available "Extract all" entries
  * Selection and navigation submenus in extraction and archiving screens are now
    organized in same way of extract here submenu: bookmarks are shown first, history,
    session history, and breadcrumb are shown in History submenu
  * Rename dialog now allows to directly switch to Move to dialog (change file path
    string rather than file name string)
  * Updated themes
  * New Mac and Tux themes
  * Old themes and additional custom themes are still available online, clicking "Check
    for Themes" button on Themes screen (Windows 10+) The application, which by default
    follows system colors, can be manually forced to light or dark mode, regardless
    system mode, creating an empty file named "light" or "dark" in the same path of the
    executable (not integrated with themes due to technical limitations)
  EXTRACTION and ARCHIVING
  * Added new command line switches, which can be used both in scripts and for system
    integration (context menus, SendTo items, .desktop files, Automator scripts)
  * -ext2neutral directly extracts archives in current path applying the "new folder"
    policy as defined in PeaZip app (non, new folder, smart new folder, or force new
    folder)
  * -ext2downloads, -ext2desktop, -ext2documents directly extract archives in
    Downloads, Desktop, or Documents path (applying app's new folder policy)
  * -ext2bookmark(1..8) extract archives in the path of the bookmarked item number 1 to 8
  * Windows context menu versions of those switches begins with -ext2multi instead of -ext2
  * Created sample scripts (.bat, .sh), W11 mini-context menu entries, SendTo items,
    .desktop files and macOS service menus for -ext2downloads, -ext2desktop,
  - ext2documents switches, in (PeaZip)/res/share/batch directory
* Thu Feb 15 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.7.1:
  CODE
  * Added "Requires restarting PeaZip" hint missing in some controls
  * Created SHA256.txt file containing SHA256 hash of each package in the release
  * Fixed Options links, now always open General tab as expected
  * Fixed restart loop switching off history checkbox, improved code against occurrence of similar issues
  * Fixed symbol lookup error experienced in some Linux ditributions with Qt5 packages
  * Fixed usupported compression method eoor experienced extracting source package using some unzip utilities
  FILE MANAGER
  * Updated translations
* Mon Feb 12 2024 PragmaticLinux <info@pragmaticlinux.com>
- Update to 9.7.0:
  BACKEND
  * Brotli 1.1.0
  * Pea 1.17
  * Zstd 1.5.5
  * 7z 24.01 beta successfully tested, but not included as backend due its beta status
  CODE
  * Compiled with Lazarus 3.0, but still compatible with Lazarus 2.x line
  * Improved loading of translations
  * Can now load language files encoded as UTF8, and as UTF8-BOM (preferred)
  * Improved support for old translation files not matching with application's version
  * Various fixes
  * Fixed -ext2simple bug, the switch is now properly working
  * Fixed Qt5 seection issue, the file browser in details mode is now set to row selection
  FILE MANAGER
  * Smart filename sorting can now be turned on/off form Options > Organize
  * (Windows) PeaZip now supports the Windows 10 and newer systems Dark Mode using zamtmn
    metadarkstyle.lpk, thanks to user contributed pull request 114.
  * Classic dark themes / high contrast mode is still supported on all Windows systems
  * (Themes) Improved "Button" alternative Tab style
  * Vertical tabs in Options screen are now themed accordingly to theme's tab style
  EXTRACTION and ARCHIVING
  * Improved the scripting generation engine:
  * In Console tab af archiving and extraction screens it is now available a new option
    for the scripting engine to use strdin/stdout pipe for creation and extraction of
    compressed TAR archives, so no intermediate TAR file needs to be saved on disk during
    those operations
  * This option does not apply to the GUI app itself (which launches the operations as
    distinct single processes), but only to scripts generated by the application, which
    can be saved to run independently in console instances
  * The option applies only to formats handles through 7z / p7zip backend
  * For extraction operation, the option applies only a single or multiple archives are
    sent to extraction scren, not while brosing a single archive (either for partial or
    total extraction)
  INSTALLERS
  * (Linux) It is now available PeaZip Portable for aarch64 Linux, the first test release
    was released built on previous version's code
  * (Windows) Improved Windows 11 mini-context menu entries, now displaying correct
    PeaZip icons; sample scripts to integrate PeaZip with W11 mini-context menu are
    available in the app inside the subfolder (peazip)\res\share\batch\Windows\Windows 11
    mini context menu
  * (Windows) Packages and configuration wizard built with InnoSetup 6.2.2
- Removed peazip-lazfileutils.patch (fixed upstream).
* Wed Jan 17 2024 Paolo Stivanin <info@paolostivanin.com>
- Add peazip-lazfileutils.patch (patch by pragmalin).
  This fix is backward compatible with Lazarus 2.x.y, because unit
  LazFileUtils already exists there too. They just moved a few
  things from FileUtils to LazFileUtils.
* Fri Dec 22 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.6.0:
  BACKEND
  * Pea 1.16
  CODE
  * All scripts are now exported as UTF-8 encoded files, without BOM
  * Improved integrity self-checking of app's binaries
  * Libraries (.dll, .so, etc) and sfx modules are now checked (as for executables, matching SHA256 hash values with whitelisted known values)
  FILE MANAGER
  * Improved file / archive manager
  * Added an icon-only Compact sidebar displaying links to most commonly used system paths
  * Compact side bar can be set visible / hidden separately from the main Side bar
  * The Compact side bar is mainly meant for use when Side bar is hidden or in tree view mode
  * Improved browsing archives with some specific TOC issues (duplicated entries for same item, duplicates names with different cases)
  * Improved smart sorting of file names
  * Improved theming
  * All alternative tab styles (Button, Links, and Tabs) can now ne either centered or left aligned
  * Link tab style is now rendered with graphic as the other styles
  * Introduced profiles to store all configuration data (everything in conf path - except Profiles subfolder) to be loaded / saved in a single pass, either for different users or for different purposes, or to easily export all the conf data to another machine
  * Profiles are stored as *.profile.7z archives in "Profiles" subfolder in conf path and can be optionally encrypted with password/keyfile
  * It is possible to load / save profiles from main menu, Options
  * Various fixes and improvements
  * Fixed breadcrumb issues in full screen and immersive modes
  * Improved handling encrypted ARC files
  * Browsing ARC archive with encrypted filenames now correctly triggers password request
  * Extraction from context menu now correctly triggers password request, and can be terminated by the user if wrong password is provided
  * Input name and path is now correctly reported during archiving / extraction / list / test operations
  EXTRACTION and ARCHIVING
  * Improved archives extraction, "Extract then move to destination" is not applied when extracting to new folder, as naming conflict analysis is not needed
* Wed Aug 30 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.4.0:
  * Add support for adding, editing, and removing archive-level comments in RAR and ZIP/ZIPX files,
    interactively (Alt+M) and from batch scripts, on single or multiple archives at once even of mixed types.
  * It is now possible to directly add files and folders to archives in Brotli, BZip2, GZip, TAR, WIM, XZ,
    Zstd, and Zpaq formats (from command line, Automator scripts, .desktop files, and context menu items),
    and it was updated the (peazip)/res/share/batch folder containing scripting and system integration examples.
- Use the new Lazarus packages.
* Thu Jul 20 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.3.0:
  BACKEND
  * 7z 23.01 (Linux, macOS, Windows)
  * Pea 1.13
  FILE MANAGER
  * Added column to display file-level comment in archives (default hidden)
  * While browsing an archive, the information popup (clicking on status bar) shows if the archive type can be edited in PeaZip
  * Updated Themes
  EXTRACTION and ARCHIVING
  * Added checkbox to manually set RAR binary for Custom / RAR compression format
  * Various fixes
* Tue Apr 25 2023 C J <c.j@tuta.io>
- Update to 9.2.0:
  BACKEND:
  * Can now use zpaqfranz https://github.com/fcorbelli/zpaqfranz as
    alternative backend for .zpaq. To use an alternative zpaq rename the
    binary as zpaq and replace the zpaq binary in /usr/lib64/peazip/res/bin/zpaq/
  CODE:
  * Fixed compression method is now saved accordingly for 7z.
  * Re-organized Help section with quicker access to online updates, Plugins,
    Themes, and Translations.
  * Privacy and Security section in main Settings tab, collecting all relevant
    functions, including Updates.
  FILE MANAGER:
  * Minor modification to themes and icons.
  * New options in Main menu, Organize (Tab bar can now be swapped with Address bar,
    Breadcrumb bar can be shown as plain text).
  EXTRACTION and ARCHIVING:
  * Can now set a custom alias name for 7z / p7zip binary, to make easier to use an
    alternative backend, in Options > Settings, Advanced tab.
  * Improved "Edit non-canonical archive types" (Options > Settings, Archive manager tab).
- Fix bin location for upx/arc/brotli/zpaq/zstd
* Mon Feb 27 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.1.0:
  * Major restyle in application's look & feel and themes, and many
    usability improvements for the file manager, and archiving / extraction screens.
  * The scripting engine was refined, with the ability to adapt the syntax
    for a specific 7z version at runtime, and to export archive conversion tasks as scripts.
  * Support for TAR, Brotli, and Zstandard formats was improved.
  * Pea was updated to 1.12, fixing for CVE-2023-24785 (this fixes bsc#1208468)
* Mon Dec 19 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.0.0:
  BACKEND:
  * Pea 1.11.
  CODE:
  * Fixes, clean up of legacy code.
  * Improved speed and memory usage.
  FILE MANAGER:
  * GUI better adapts to size and preference changes.
  * Selecting one of the available tool bars (archive manager, file manager,
    image manager) restores its visibility if the Tool bar is hidden.
  EXTRACTION and ARCHIVING:
  * Added new options for 7z/p7zip backend.
  * Improved support for TAR format, and for formats used in combination with TAR.
  * Improved support for ZPAQ and *PAQ formats.
  * Updated compression preset scripts.
  * Updated plugin for PeaZip.
- Rebase all patches.
* Sun Oct  9 2022 C J <c.j@tuta.io>
- Update to 8.9.0:
  BACKEND
  * Pea 1.10
  CODE
  * Password Manager is now re-set only from Options > Settings >
    Privacy, Reset Password Manager link
  * Various fixes and improvements
  * Correctly displays folder size inside ZIP archives if applicable
  * Cleanup of legacy code
  * Improved performances and memory management for browsing archives
  * Improved opening folders after task completition
  * Improved detecting root extraction directory
  * Archive conversion procedure now opens target directory only once,
    after final compression step
  * Task window can now show temporary extraction work path from context
    menu right-clicking on input and output links
  FILE MANAGER
  * Added progress bar while opening archive files supported through 7z
    backend; progress indicator is not visible when archive pre-browsing
    is disabled in Options > Settings > General, Performance group
  * Improved Clipboard panel, can display tems size and modification date
  * Improved quick navigation menu (on the left of the Address bar)
  * Can now set password/keyfile, and display if a password is set
  * Can now display info on current archive / selection / clipboard content
    duplicating function of staus bar; the new Info entry is also featured
    in main menu, Navigation group
  * Can now toggle bookmarks, history, and clipboard views in the Status bar
  * Improved Style button
  * Right-clicking Style shows main menu as context menu
  * Settings is now reachable from Style button in Tool / Address bar
  * Updated theming engine
  * Address bar color can now be changed separately from Address field color
  * Tab bar color has now more options
  * Improved existing Themes to take advantage of the new options
  * Updated Tuxedo theme
  * New Droid theme
  EXTRACTION and ARCHIVING
  * Changed default working directory to output path, as more consistent
    with behavior of similar applications on non-Windows systems
  * Added context menu entry for "Add to separate archives" action, shown
    when applicable in file browser screen
  * Improved archiving and extraction context menu, to make easier to add
    files and folders (or open search) from bookmarks abd history items
  * Improved test after archiving
  * Empty archives are reported as warnings
  * It is now possible to set the sequence of tasks to stop for auto-test
    results (otherwise it will stop only in case of error) from Options >
    Settings > Advanced
  * More information is available clicking status bar string in archive
    creation and extraction screens: task type details, temp work path
    (if applicable), input zise, output path with total size and free space
* Mon Sep 19 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.8.0 (bsc#1202690):
  BACKEND
  * 7z 22.01
  * Pea 1.09
  CODE
  * Various fixes and improvements
  FILE MANAGER
  * Improved GUI for more flexibility to better adapt to multiple environments with different visual styles
  EXTRACTION and ARCHIVING
  * Added option to test archive after creation, for formats supporting test routine, in Options > Settings, Archive manager tab
  * Added timestamp precision option in Archiving screen, Advanced tab, applies to ZIP and TAR/pax formats
  * Added timestamp precision option in Archiving screen, Advanced tab, applies to ZIP and TAR/pax formats
  * Added options to save owner/group ids and names, available in Archiving screen, Advanced tab
- Set correct category in the desktop file (bsc#1202690)
* Sun Jun 26 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.7.0:
  BACKEND
  * 7z 22.00
  * Pea 1.08
  CODE
  * Can now optionally check hash of backend binaries called by PeaZip in order to detect modified ones
  * Can now optionally hardcode paths of backend binaries, configuration, and non-binary resources directories as absoulte paths at compile time
  FILE MANAGER
  * Added "Open in a new tab" to breadcrumb navigation menu
  * Can now export content of navigation/search filter as CSV, from column's header menu, and Main menu > Navigation submenu
  * CSV separator can now be customised from Options > Settings, General Tab, on the right of Localization selector
  * File manager now displays file size and compressed file size of directories inside archives, CRC column displays files and sub-directores count for directories
  * Many visual enhancements
  EXTRACTION and ARCHIVING
  * Can now remember default archive creation action (force new archive, add, update, sync...)
  * Improved displaying directory size in archive creation screen: items are now recursively enumerated asynchronously (non blocking) by default, so it is possible to proceed with archiving operations (confirm, cancel, modify parameters...) without needing the input count to be completed
  * Re-organized Archive manager settings page in Options > Settings
  * For Zpaq format now "Absolute paths" extraction option is enabled by default (in Advanced tab of extraction screen)
* Thu Apr 14 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.6.0:
  BACKEND
  * Pea 1.07
  * 7z updated to 21.07
  * (Linux) Zstd 1.5.2
  CODE
  * Fixed dictionary size for ZIP using XZ compression
  * Compiled with Lazarus 2.2.0
  * Various fixes
  FILE MANAGER
  * Improved theming
  * New .ico and .png icons are now available in (peazip)/res/share/icons
    directory for customizing the application on Linux, macOS, and Windows systems
  * Simplified organization of UI layout
  * Added link to devices mounted in /var/run/media in filesystem treeview, when applicable
  * File / archive browser can now alternatively display larger details,
    and large list modes (from Style menu on status bar) in order to improve readability and touch usability
  EXTRACTION and ARCHIVING
  * Added "Immediate execution" option for Profiles and Presets, in Add button's dropdown menu
  * Added command line switches to compress items using one of the compression presets
    or loading a saved custom compression setting
  * Added option to not immediately save edited files into archive, keeping changes for further editing
    (or for manually saving to archive from context menu, More submenu)
  * Labels in status bar of Archiving and Extraction screens are clickable to show synthetic information about the task
  * Improved compression settings
  * Improved usage of Layouts
- Switch from GTK2 to QT5
* Wed Jan 26 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.4.0:
  BACKEND
  * Pea 1.05
  * 7z 21.06 (console) used by default on Darwin/macOS, Linux, and Windows
  * p7zip, and szcnick's p7zip (fork of p7zip) syntax is fully supported
    and can be used as alternative replacing (peazip)/res/bin/7z/7z binary
  CODE
  * Fixed issues when temporary work path is set to user's temp
  * Fixed smart extraction not able to remove extra level of nesting
  FILE MANAGER
  * Added single and multi core performances benchmark, in main menu Tools > System benchmark (pea)
  * The benchmark performs integer and floating point arithmetic operations
  * Benchmark result unit is arbitrary and only meant to allow comparison between different platforms
  * For reference 2020 MacBook Air M1 score is 100 (single core) and 515 (multi core) for aarm64 build
  * (Darwin/macOS, Linux) File manager columns' menu is available righclicking status bar
  * Added links to Volumes, Applications, and System/Applications in navigation treeview
  * Added auto-configured custom apps for "Open with" submenu
  * Open command prompt here function now working
  * PeaUtils launching from PeaZip now working
  * Language can now be changed from dropdown menu from General settings tab (main menu, Options > Settings)
  * Previous method allowing to manually select the language file is still available
    from the link before the dropdown menu
  EXTRACTION and ARCHIVING
  * New option to not stop sequences of archive test tasks unless an error is encountered
  * From main menu, Options > Settings, Advanced tab set "Stop to inspect report for error,
    list" instead of default value "Stop to inspect report for error, list, test"
  * With this setting, a successful archive test closes on completion unless an error is foud in the archive and test fails,
    in which case error message (and full report) is shown to user and needs to be dismissed
    before continuing with following test in sequence
  * Improved management of temporary work files
  * 7z/p7zip work files during compression are now inside peazip-tmp subpath,
    if work directory is set to Custom or User's tem
* Tue Jan 25 2022 Dario Faggioli <dfaggioli@suse.com>
- 7z is expected to be in ../res/bin/7z
  * this is mentioned in comment 5 of bsc#1195041 (even if the bug
    itself is about something else)
* Wed Nov 17 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.3.0:
  BACKEND
  * Total max length of command scripts generated by the application
    can be customized from 32KB to 2MB from
    Options > Settings > General, Performances
  * szcnick/p7zip regressed from 17.04 to 17.02 due a possible bug
    handling some zip files different versions / branches of p7zip
    (provided same syntax is employed) can be used simply replacing binaries
    in (peazip)res/bin/7z path
  * Updated to pea 1.04
  CODE
  * Improved compliance with Open Desktop specifications: configuration
    is now saved in $XDG_CONFIG_HOME/peazip directory; if $XDG_CONFIG_HOME
    is not defined configuration is saved to $HOME/.config/peazip.
    To import existing configuration simply copy content of
    $HOME/.PeaZip directory to the new location
  * Fixed possible error with progress bar
  * Fixed possible error not asking password opening some encrypted archives,
    and reduced false positive cases in which it the application
    suggested to provide a password
  * Fixed error reporting information about multi volume archives
  * Fixed error in file manager selecting files with same
    characteristics of selected item
  FILE MANAGER
  * Shortcuts to /media, /run/media, and /mnt (if not empty) are now
    featured in navigation tree, under filesystem group
  * Improved automatically configuring XFCE apps alternatives in
    "Open with" menu: Mousepad, Midori, Parole, Ristretto
  * Fixed theming issues with GTK2
  * Column header's context menu is now accessible alternatively
    right-clicking the status bar
  * Improved theming
  - Added Color temperature option, to adapt application to DE using
    warmer or colder colors
  - Added Highlight tabs option (default on) highlighting rows or columns
    containing tabs with alternate color
  * Options > Settings > General, Privacy / Reset group, Working directory
    is now set to system's temp by default
  * Options > Settings > General, Privacy / Reset group now allows to silently
    skip deletion of locked temporary work files (default on, consistently with
    behavior of most applications of this type); temp work files can then be
    optionally deleted separately:
  * Options > Settings > File manager now allows to set the multiple-byte unit:
    binary, 1024 (IEC kibibyte), or decimal, 1000 (IEC kilobyte),
    or none (exact byte size)
  * Options > Settings > File manager now allows to customize the list of
    preferred algorithms for calculating file checksum and hashes; all preferred
    algorithms in the list will be performed in a single step when
    it is required to checksum / hash files.
  EXTRACTION and ARCHIVING
  * Added Deflate and Deflate64 compression options to 7z format
  * Improved -ext2here, -ext2folder (-alias -ext2smart), and -ext2newfolder
    functions adding command line options:
  * -i ignore delete original archive after extraction settings
  * -o output directory in next parameter
  * -p password in next parameter
* Thu Sep 30 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to version 8.2.0
  * BACKEND
  * Updated Brotli to 1.0.9 version
  * Added read support (browse / test / extract) to Lzip .lz file type
  * Added support for .apkm, .apks, and .aab packages Android package formats
  * Updated Pea 1.02
  * Updated Zstd 1.50
  * Updated p7zip 17.04
  * CODE
  * maximum length of CL generated on Linux systems is now increased to
    128 K characters in contrast to much more limited 32 K characters
    allowed on Windows systems
  * FILE MANAGER
  * Improved system directories shown by default in navigation tree
    on the left of file manager
  * Updated list of apps automatically detected for Open with submenu;
    apps and scripts can be customized in Options > Settings, Applications tab
  * Enabled System tools submenu in context menu > File manager
  * New Ctrl+Alt+A link to autoadjust file browser columns
  * Themes: added "Presets" link on the right of Application accent color picker,
    allowing to quickly customize both application and text accent colors accordingly to
    common color themes of reference Operating Systems e.g. Mint, Ubuntu, Windows
  * EXTRACTION and ARCHIVING
  * Added XZ (Linux, Windows) and Zstd (Linux) as optional algorithms for ZIP/ZIPX compression,
    from Advanced tab in archiving / conversion screen
  * Improved extraction
  * Improved raw file spanning, it is now possible to submit multiple separate
    input files at once to be split to specified size
  * Improved support for .xxxaa spanned files from Unix/Linux split command
  * New option for default behavior at application startup: Extract all here (smart new folder)
  * Added support (as container files) to .whl Python archives and .gem Ruby gem archives
  * Added option to extract all, selected or displayed items to extraction dropdown menu,
    replicating Extract button context menu
  * Added actions to Test all, selected or displayed items in Test button context menu
- Rebase peazip-desktop.patch
* Thu Jul 15 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to version 8.0.0
  * BACKEND
  * Pea 1.01:
    + Added exit codes to functions for easier integration with
    third party software and scripts
    + Running PEA in batch_report and hidden_report mode automatically
    saves task log without further user interaction
    + Fixed: hidden and hidden_report modes do not flash the GUI
    before hiding it
    + Updated online documentation at https://peazip.github.io/pea_help.pdf
  * FILE MANAGER
  * Added support for .xappx, and various Open Packaging Conventions
    filetypes (.3mf, .vsdx, .mmzx, .aasx, .slx, .scdoc) files,
    218 file extensions supported
  * Added text completion for search field
  * Checksum/hash files can now be set to perform a single
    algorithm (faster), by default SHA256
  * Dragging a single archive file on file manager screen, the archive
    is now opened without requiring further interaction
  * Improved preview and open with functions
  * Improved random password generator in main menu,
    Tools > Create random password / keyfile
  * Improved smart sorting of file names
  * Improved status bar
  * Improved support for non-canonical archive types
    (containers, disk images, installers...) with new options in
    main menu, Options > Settings > Archive manager
  * Improved theming: can now optionally display grids with
    alternate color for better readability
  * EXTRACTION and ARCHIVING
  * Added "Force typing passwords interactively" option in password
    screen that forces to always type password in the native
    backend interface
  * Can now edit existing 7Z-compressed sfx archives
  * Improved "TAR before" option, which saves multiple input to
    TAR archive before compression step
  * It is now possible to customize the default action to perform
    when a file type associated with PeaZip is double-clicked on
    the system (or any time a single file is sent as input to PeaZip)
* Tue May 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 7.9.0
  * BACKEND
  * Pea 1.00
  * Added 512 bit hash functions to PeaUtils menu
  * FILE MANAGER
  * Improved theming: new customizable parameters
  * Spacing [small, medium, large] to increase spacing in file
    manager and row height in tables
  * Zooming [100%% to 150%%] to enlarge icons and graphic elements
  * Working directory is now set to by default to: user tmp for
    preview operations, output for other operations
  * "Extract everything for" preview for special file types now
    uses working directory
  * "Interactive extraction" now uses working directory
  * EXTRACTION and ARCHIVING
  * Improved interactive extraction, which is now set on by
    default in extraction screen
  * If no naming conflict is detected, the output data is now
    moved, if possible
  * Improved support for ZPAQ format
* Wed Mar 24 2021 ecsos <ecsos@opensuse.org>
- Update to 7.8.0
  * BACKEND
  - PEA 0.77
  * CODE
  - (Linux) Alternative Qt5 build is now available as portable
    package
  - If a setting requires to restart PeaZip (localization, system
    integration, change work folder) it is told in the hint text
    for the item
  - Various fixes and improvements
  * FILE MANAGER
  - (Windows) Drag&drop now allows to drag-extract files directly
    to other applications, previoulsy it was possible to
    drag-extract to the system only - 2021 03 22 fix for Windows
    32 bit version, sources and legacy Windows 32 bit packages
    were republished and online hash values were updated
  - Righclicking an element on the breadcrumb it is now possible
    to use context menu functions on it - e.g. display properties,
    open the path in system's file explorer, open command prompt
    here, etc
  * EXTRACTION and ARCHIVING
  - Interactive extraction option (checked by default on Windows)
    enables two-step extraction for all archive types supported
    through 7z/p7zip: content is extracted to a fresh folder and
    then moved to actual output destination with standard
    system's calls.
  - When interactive extraction is used, all unneeded levels of
    directory nesting are removed, and conflicts with existing
    files are prompted interactively to user.
  - Unchecking the option, it is possible to perform
    single-step extraction as in previous versions, with policy
    based directives to resolve naming conflicts without
    needing user interaction (recommended when creating
    scripts).
  - It is now possible to set custom extensions for "Extract
    everything for" in Options > Settings > Archive manager,
    Extract group
  - It is now possible to replace archive extension with a custom
    extension from archiving screen, Advanced tab
  - In res/presets/custom directory are provided some pre built
    compression settings for comic book archive formats which
    uses the new custom extension feature
  - Priority for archiving and extraction tasks can now be
    permanently set from Options > Settings > General, Tasks
    priority
  - (Windows 7+) Global progress is shown in application's icon
    in taskbar
* Mon Mar 15 2021 ecsos <ecsos@opensuse.org>
- Update to 7.7.1
  * BACKEND
  - Pea 0.76
  - UPX was removed from Windows packages due the amount of false
    positives triggered in (low quality) security software; it is
    possible to add UPX support installing Additional Formats
    Plugin, or downloading and copying the most up to date UPX
    executable in res\upx subfolder in PeaZip's directory
  * CODE
  - Command line -ext2simple and -ext2simplefolder can now accept
    also empthy output path (extract to archive's path)
  - ext2simplefolder as -ext2folder (switch -*folder) apply
    smart folder policy, while -ext2simple and -ext2here
    ignores it
  - Updated web search (Ctrl+Alt+F3)
  - Updated Windows installers to work with recent versions of
    InnoSetup (.exe) and MSIWrapper (.msi)
  - Various fixes
  - CPUAARCH64 now disable Intel ASM to allow build on ARM64
    architectures
  - fixed adding multiple .enc suffix
  - fixed various issues with non-English localizations
  - fixed issue with preview for special file types (bat, exe,
    html) resulting in extraction instead of preview
  - improved handling special characters in password for arc,
    rar, and pea formats
  - (Linux) improved handling of special characters in
    filenames
  - (Linux) fixed issues with smart folder option
  * EXTRACTION and ARCHIVING
  - PEA compression and decompression can now be cancelled from
    the GUI
- Drop peazip-fix_aarch64.patch because now in upstream.
* Sat Feb  6 2021 ecsos <ecsos@opensuse.org>
- Update to 7.7.0
  * BACKEND
  - (Linux) Can now optionally use system p7zip, if installed,
    from Options > Settings, General tab requires p7zip-full
    (or equivalent package) to be installed in order to have a 7z
    binary compatible with PeaZip's requirements in terms of
    syntax and features
  * CODE
  - Various fixes
  * FILE MANAGER
  - Added shortcut Ctrl+W to close window, consistently with
    conventional use in WinRar and Windows file explorer
  - Improved control over temporary work directory, used when the
    archive is created or edited, during drag and drop extraction
    (Windows), and content preview
  - Output: faster as no copy to destination is needed, more
    secure as no content is unpacked/decrypted outside of the
    intended destination path
  - Output, preview in user's temp
  - User's temp (as conventionally used by most applications):
    in case of failure for any reason, user's temp folder is
    the single place to look for orphaned data and can be
    safely cleaned
  - None, user's temp if needed: allows exceptions to perform
    drag and drop extraction and preview using user's temp
  - None: no exceptions allowed, no temporary work data is saved,
    this does not allow to perform neither drag and drop
    extraction nor preview, as archive content can't be
    transparently unpacked and passed to system's drag & drop
    handler, nor to the associated application
  * EXTRACTION and ARCHIVING
  - Added read support to .appxbundle format
* Fri Jan 15 2021 Max Lin <mlin@suse.com>
- BuildReqruies p7zip-full on Leap version greater than 15.1
* Mon Jan  4 2021 ecsos <ecsos@opensuse.org>
- Update to 7.6.0
  * BACKEND
  - (Winodws, ReactOS) McMilk codecs in 7z\Codecs path are now
    automatically checked at PeaZip startup, in order to disable
    them (moving in 7z\Codecs\bk) on systems not capable to run
    them (as XP or ReactOS), and re-enable them on other systems;
    this works for both Portable and installable packages without
    requiring manual intervention
  * CODE
  - Various fixes
  * FILE MANAGER
  - (in left navigation panel) Archive treeview is now
    automaticaly updated accordingly to browsing in file manager
    area
  - This option can be fine tuned in Options > Settings >
    Archive manager
  - Various usability improvements
  - Can now set current path as default archiving or extraction
    path
  - Options > Settings > General, Advanced, and Archive manager
    tabs reorganized
  - Improved and updated themes, and simplified Theme tab
  * EXTRACTION and ARCHIVING
  - Improved handling ZIP files with code pages different than
    local
  - Can now customize code page for reading/writing filenames
    in ZIP archives, from Options > Settings,
    Advanced tab it is possible to set:
  - Local code page, then UTF-8 for sysmbols outside local
    code page (default)
  - Force UTF-8 for non-ASCII characters
  - Force local code page
  - Use a custom code page: an arbitrary code page can be
    entered by user (the host machine needs to support the
    code page to run the tasks, otherwise tasks can be saved
    as scripts and run on different machines)
  - Text encoding entry is now accessible also from application's
    file browser context menu, and in Archiving and Extraction
    screens context menus
  - Within PeaZip file manager it is now possible to use
    copy/paste shortcuts Ctrl+C (or Ctrl+X) / Ctrl+V to extract
    items from archives to filesystem
  - If clipboard is set to keep multiple selection operations
    at once:
  - Copy/paste extraction is possible form multiple archives
    at once
  - It is also possibile to mix cut/paste and extraction
    operations
  - Extraction targets the file system, it is not currently
    possible i.e. to directly paste compressed items from
    archive A to archive B
- Changes from 7.5.0
  * CODE
  - Various fixes
  * FILE MANAGER
  - Create new folder is now also available for 7Z/p7Zip and RAR
    supported archive types
  - Improved file renaming routines
  - added function to cutting file names at specified lengtt
  - added function to replace / remove non-ASCII characters
  - all quick rename functions (lowercase, replace string,
    etc...) are now also available when browsing 7Z/p7zip and
    RAR supported archive types
  - Updated icons in embedded theme and added icons to
    distinguish common archive types
  - Updated Ten theme
  * EXTRACTION and ARCHIVING
  - Added "Extract everything for special file types"
    (to 7Z-supported archive types) to optionally extract the
    entire archive (or current path) to preview special filetypes
    which usually needs external data to properly run, in example
    .html, .bat, and .exe files
  - From Options > Settings > Archive manager, Extract group is
    possible to customize "Extract everything for..." behavior
  - Never use special preview, Ask, Always (default)
  - Extract entire archive (default) or Extract displayed
    items only (items in current path, or matching search
    filters) which can be faster than extracting the entire
    archive
  - Archive timestamp preservation directive is now also applied
    to rename and delete operations
    (previously only for add / update)
  - Options > Settings > Archive manager, Extract group: added
    option to auto close PeaZip after extraction if no browsing
  - actions took place (default off), useful in example if a
    downloaded file was opened for quick inspection before
    extraction
  - Options > Settings > General (Windows): added options for
    locking or hiding target window during drag and drop
    operations, by default target window is hidden and locked
    while the operation is running
  - Out of the box default compression levels are set to fast for
    ZIP and 7Z formats
  - compared to previous ZIP normal default, ZIP fast is over
    400%% faster providing 2%% worse compression ratio, and 7Z
    fast is 25%% faster providing 3%% better compression ratio
  - compared to previous 7Z normal default, 7Z fast is 500%%
    faster providing 5%% worse compression ratio
  - please note compression levels and compression presets
    works as usual, the new settings are meant only to provide
    novice users better performance balance for general purpose
    tasks
  - Modified existing preset scripts
  - 10 from faster zip to fast zip
  - 12 (Linux) from .tar.zst to .7z using Zstandard compression
    (which requires single pass)
  - Test mode always show details about single files in archive
  * WINDOWS & LINUX INSTALLERS
  - (Windows XP) additional 7z codecs introduced in 7.4 line,
    incompatible with Windows XP, are deactivated when installed
    on XP machines, consequently the error messages are no longer
    triggered when using 7z backend
* Mon Oct  5 2020 ecsos <ecsos@opensuse.org>
- Update to 7.4.2
  * BACKEND
  - (Linux) p7zip 16.02 superseded by sznick/p7zip fork 17.02,
    not available for legacy 32 bit platforms added support for
    FLZMA2, LZ4, and Zstd compression algorithms in .7z format
    algorithm selection dropdown is now common to all platforms,
    unsupported algorithms for one platform are preceeded with /
    (currently unsupported /Brotli, /Lizard, and /LZ5 on linux)
  * CODE
  - Various fixes
  * FILE MANAGER
  - (Windows) File manager now displays icons for exe files for
    better usability, using a separate thread; previously the
    feature was enabled only if browser was set to show thumbnails
    In-archive Extract and open with PeaZip and Preview with
    PeaZip now forces trying to open file as archive, as in Open
    as archive menu entry
  * EXTRACTION and ARCHIVING
  - (Windows) Drop target window is locked, as in WinRar, until
    drag and drop operation is completed
    If password contains characters that can be troublesome if
    used in scripts (i.e. quotes) it is now possible to
    interactively enter password in console to create / extract
    archive types handled through 7z/p7zip, ARC, and RAR backends
* Sat Sep 26 2020 ecsos <ecsos@opensuse.org>
- Update to 7.4.1
  * BACKEND
  - Pea 0.74
    Introduced PEA format revision 1.3, supporting multiple
    cascade authenticated encryption, each cipher with 256 bit key,
    in EAX mode: AES+Twofish+Serpent, Twofish+Serpent+AES, Serpent+AES+Twofish
    Fixed a bug preventing extraction of PEA archives in case of naming conflicts
  * CODE
  - Fixed Fast-LZMA2 dictionary sizes
  - Fixed error 127 erroneously raised in some cases
  * FILE MANAGER
  - Improved directories smart sorting in file manager
  - Improved tabs
  - closing last tab collapses tab bar
  - mouse middle button closes tab
  * WINDOWS & LINUX INSTALLERS
    (Windows) Fixed context menu entry "CRC, hash and file tools",
    now pointing by default to "Checksum/hash (common algorithms)"
    consistently to all other calls form PeaZip
* Fri Sep 25 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.4.0
  * GUI refresh and improves working with 7Z, ARC, RAR, and ZIPX
    archive types.
  * It is now possible to use new fast compression algorithms in
    7Z format: Brotli, Fast-LZMA2, Lizard, LZ4, LZ5, and
    Zstandard are now available, providing faster-than-Deflate
    compression with better speed-to-compression-ratio
    efficiency.
  * RAR archives are now fully read-write supported from PeaZip
    if rar executable is featured in the system: it is possible
    to update, edit, rename, and delete files in existing RAR
    archives, and more RAR-specific options are supported (set
    comment, lock archive, header encryption, set recovery
    records percentage).
  * ZIPX archives can now be edited, and it is possible to
    optionally use .zipx extension when creating non-Deflate
    compressed .zip archives.
  * It is now possible to repair ARC and RAR files, and even to
    attempt recovery if the archive cannot be opened for
    browsing.
- Refreshed peazip-desktop.patch
- Add optional support for less common archiving formats:
  arq, brotli, zpaq, zstd (fixes boo#1175933)
* Wed Jun 24 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.3.2
  CODE
  * Various fixes
  FILE MANAGER
  * Added support to more file extensions:
    + .cramfs compressed ROM/RAM file system images
    + .ext, .ext2, .ext3, and .ext4 filesystem images
    + .hfsx filesystem images
    + .qcow, and .qcow2c QEMU disk images
    + .scap, and .uefif firmware files
    + .mub, .pkg, and .ppmd compressed files
  * Archive browser now will automatically ask for password to
    open files with unreadable TOC, for all formats supporting
    TOC encryption, e.g. archives encrypted with "Encrypt also
    file names" option
  * Fixed browsing of encrypted ARC files
  * Fixed: can now delete files within WIM archives
  EXTRACTION and ARCHIVING
  * Setting Custom compression type optionally aut-configures
    PeaZip to use RarLab's Rar.exe as compressor; if
    libre_directive option is set to 2 (most restrictive, not
    allowing closed archive formats), rar creation will be not
    allowed in any case
  * Rar.exe will be set to use PeaZip's work dir as other
    backend binaries
  * For RAR archives it is possible to set
    compression level, from store to maximum
    + action: new archive, add, update, freshen, sync with disk
    + spanning in multiple volumes password, optionally with two
    factor authentication (password + keyfile)
    + create RAR5 or legacy RAR4 archive
    + (RAR5) set dictionary size 1..1024 MB
    + (RAR5) use BLAKE2 hash instead of CRC checksum
    + Create self extracting RAR
    + Solid archive
    + Recovery records
    + Save files open for writing
    + Save NT security information
    + Save NTFS streams
    + Set archive time to last modified object
  * Improved support for more RAR options is planned in future,
    to allow efficient RAR creation from PeaZip GUI, providing
    RarLab's WinRar is installed in the system and Rar.exe is
    available.
* Tue Jun  2 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.3.1
  BACKEND
  * Zstd 1.4.5
  CODE
  * Various fixes, improved progress bar accurancy for multiple
    tasks
  FILE MANAGER
  * Fixed folder sorting, now folders are always grouped before
    files
  * Improved theming, window and toolbar colors can now be
    customized
  * New Graphite, Mocha, and Senape themes with intermediate
    color tones
  * System-rendered widgetsets are not affected by theme colors
    as native drawing methods were not bypassed by theme
    implementation
  EXTRACTION and ARCHIVING
  * Added support for .zstd extension, as used in compressed cpo
    in new rpm installers
  * Updated sfx module for p7zip
* Mon May 18 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.3.0
  BACKEND:
  * Pea 0.71 with PEA file format revision 1.2
  CODE:
  * Various fixes
  FILE MANAGER:
  * Added BLAKE2S and BLAKE2B hashes to
  * File manager's hash (for file hashing and deduplication)
  * File tools set of hashes
  * Optional hash for raw file split
  * Optional hash for PEA format
  * Added support for opening as archive modern Linux package
    formats: .appimage, Ubuntu's .snap, and FreeDesktop Listaller
    .ipk
  * Browser now uses smarter sorting for file/directory names
  * By default now PeaZip tries to open archives containing
    errors
  * Errors detected browsing the archive are now notified in
    status bar, even if it is possible to list archive's content
  * "Try to open archives contining errors" can be disabled in
    Options > Settings > Archive manager
  * Fixed some cases not allowing secure deletion and zero
    deletion of files
  * Improved deletion of temporary work files
  EXTRACTION and ARCHIVING:
  * Added option to not ask confirmation for delete after
    archiving/extraction, in Options > Settings > Archive manager
  * Delete is not triggered if errors are detected
  * Delete is triggered after extraction only in case of
    complete extraction (extract all)
  * Added option to set archive time from most recent file in
    archive, for all 7z/p7zip formats
  * Added option to improve Brotli compression using more memory
    at cost of small impact on speed (archives created with this
    option may not be compatible with some Brotli decompressors)
  * Added option to improve Zstandard compression using more
    memory at cost of small impact on speed
  * Added new advanced options to custom compression settings
    files, keeping compatibility with setting files created with
    older versions
  * Presets were rebuilt accordingly new format
  * Two new presets: Medium compression with 7z fast, and Fast
    compression with 7Z fastest
  * It is now possible to cancel all tasks of a sequence in the
    case one of the archiving / extraction task fails
* Wed May  6 2020 aloisio@gmx.com
- Update to version 7.2.2
  * Improved archive creation procedure, saving settings for
    file spanning, dictionary, word, passes, and block size.
  * Current compression settings defined in the GUI can be saved
    into custom compression settings files, and default
    compression presets can be customized / replaced.
  * ZPAQ support was improved optimizing compression, and
    enabling AES256 encryption, restore to absolute paths, and
    extraction of all versions of files contained in the archive.
  * Alongside many other improvements and fixes, it is now
    possible to automatically close PeaZip when task completes,
    directly send files to encrypted 7z archive from context
    menu, save file hash and information, and to display SMART
    disk health data.
- Refreshed peazip-desktop.patch
* Mon Apr 27 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.2.1
  * improve and fix archive creation features introduced in
    the previous release
    + save advanced options
    + save and load custom compression profiles
    + customize compression presets
  * it is now possible to directly add files to encrypted 7z
    archive from context menu
  * new SMART disk iformation tool is available in File Manager
    > System tools.
* Wed Apr  8 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.2.0
  CODE:
  * Various fixes and improvements
  FILE MANAGER:
  * Extended options to manually update edited files in archive
    (consistently with update dialog) in context menu > more submenu
  * it is now possible to update archive and discard temp edit
    files (as in auto update dialog Yes/Clear option), and to
    discard edits without update
  EXTRACTION and ARCHIVING:
  * Added option to automatically close PeaZip when task
    completes
  * Added options to save and load custom compression settings
  * Menu entries are available in main menu > Layout (in
    compression screen) and in compression presets context menus (in
    file browser and in compression screen)
  * Compression settings are saved by default to "Compression
    settings" folder in same path of PeaZip configuration
  * Password and keyfiles are not saved in custom compression
    settings, to manage passwords safely see instead main menu >
    Tools > Password manager
  * Volatile, context dependant variables can be saved alongside
    non-volatile ones, but will be lost in subsequent uses unless
    the custom setting is reloaded (in Options > Advanced volatile
    variables can be shown in italic font)
  * Presets for archive creation / conversion are now rewritten
    to use new compression setting mechanism, new presets supersedes
    both old presets and favourite formats menu entries
  * Presets are saved in PeaZip\res\presets folder, in PeaZip's
    program path; apart for being saved separately they are standard
    compression setting files and can be used as such
  * To customize an existing preset with a custom compression
    settings file, copy the desired custom compression settings file
    in presets folder, in place of one of the existing preset files
  * Optionally, editing the compression setting file is possible
    to change its displayed file name, the name that will be shown
    by PeaZip in presets menu
  * New presets: ZPAQ ultra, ZPAQ, ARC, Brotli, Zstandard
  * Extended non-volatile options saved to configuration (and
    compression settings) 7z/p7zip advanced compression options for
    dictionary, word, passes and block size are now remembererd
  * File spanning options are now remembered
  * Improved support for ZPAQ format
  * AES256 encryption, supported by design by the format, is now
    enabled
  * Compression settings were optimized for better results
  * From Advanced tab of extraction screen are now supported
    following options: Restore files to original absolute paths;
    Separate extraction of all revisions of the archive; Overwrite
    existing files; Test operation is now enabled
  * ZPAQ is now available in presets at medium and ultra
    compression formats
* Mon Mar  9 2020 aloisio@gmx.com
- Update to version 7.1.1
  * Improved file editing in archives and file renaming
  * Added support for Microsoft MSIX and ESD package formats.
* Sun Feb  2 2020 aloisio@gmx.com
- Update to version 7.1.0
  * Introduced read / write support for Brotli and Zstandard
  * Direct extraction from PeaZip's file browser is now easier
  * Improved management of compressed TAR files
  * More dictionary sizes were made available for LZMA / LZMA2
    algorithms, and ZIP / BZip2 method has been added to
    compression presets.
  * Misc updates
* Sun Dec 29 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.0.1
  * Several under the hood enhancements for the application's
    GUI, with speed and memory management optimizations,
  * Improved support for high DPI, auto scaling for all UI
    elements and graphic, and updated themes and icons.
  * PeaZip can now automatically open tar archives inside tar.*
    compressed files, navigate with extra mouse buttons, hot
    swap drag and drop from standard and custom mode, it is now
    easier to detect duplicate files and analyze content of
    folders from the application's file manager.
* Tue Dec  3 2019 Luigi Baldoni <aloisio@gmx.com>
- Fix Leap 15.2 build
* Mon Dec  2 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.0.0
  BACKEND:
  * PEA 0.66
  FILE MANAGER:
  * Added option to automatically open tar archive inside tar.*
    compressed files
  * Option is on by default, can be set in Options > Settings >
    Archive manager
  * Drag & drop can now be hot swapped between standard and
    custom mode while using the application
  * Improved finding duplicate files, both with crc/hash and
    quick duplicate check: Info column shows "D" for duplicate
    for each copy of file with same digest value, except the last
    copy found
  * Sorting files for Info column allows to quickly select (and
    delete) duplicate items
  * Sorting files for checksum/hash column allows to easily
    compare identical files as in previous versions
  * New function to analyze content of folders in file browser
    (from column header menu)
  * Info column marks empty folders with "E"
  * Checksum/hash column shows content of folders: number of
    directories, number of files, and total size
  * New scaling mechanism for better support of high DPI in
    PeaZip and Pea executables
  * UI elements are scaled at run time at discrete steps zooming
    up to 10x of design time size, using Lazaruz LCL scaling
  * Graphic is accordingly scaled at run time, accepting
    arbitrarily sized graphic sources
  * Embedded 16 and 32 pixel icons are currently provided with
    3x definition (48 and 96 pixel respectively) to provide high
    quality graphic up to 300%% scaling
  * New themes for PeaZip version 7+ uses 8 or 32 bit PNG with
    transparency, and currently provides 16 and 32 pixel icons
    upscaled to 3x definition
  * New Windows icons for menus and file types; new icons allows
    to better distinguish supported file types, at large and
    small resolutions
  * When a single file of unsupported format is passed as
    parameter, the application lets the user decide if to try to
    open it as archive or to add it to new archive
  * Various fixes
  * Fixed System benchmark tool
  EXTRACTION and ARCHIVING:
  * Improved progress bar accuracy
  * Option to delete input files after task completion is now
    globally applied to all archiving / extraction functions
  * Also batch version of direct archiving / extraction
    functions now apply the deletion on completion policy
    accordingly to the application's configuration
  * Alternative versions of batch commands are now available in
    order to explicitly ignore deletion on completion policy,
    with "i" appended after function name: -add2peai,
  - add2crypti, -add27zi, -add27zmaili, -add2separate7zi,
  - add2sfx7zi, -add2sfx7zmaili, -add2zipi, -add2zipmaili,
  - add2separatezipi, and -ext2herei, -ext2folderi, -ext2toi,
  - ext2tofolderi, -ext2simplei, -ext2simplefolderi
  * Fixed and improved -add2split batch command, can now accept
    multiple input files and folders (if more than one file is
    passed as input it will be consolidated in a tar archive)
* Sun Sep  1 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.9.2
  * improves authoring of existing archives, introducing support
    for editing files in archives, for adding files to a specific
    subfolder inside an existing archive and asking for
    confirmation if items with same name exists in the archive.
  * can now display remaining time for archiving / extraction
    operations, and the new Windows packages improves managing
    file associations and application's localization.
* Sun Aug 25 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.9.1
  FILE MANAGER:
  * Configure application and file associations link replicated
    in Settings, Archive manager tab
  * Fixes in editing files in archives
  * Updated translations
* Sun Aug 18 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.9.0
  CODE
  * Updated links of online resources to https form
  * Various fixes and improvements
  FILE MANAGER
  * For archive types supported trough 7z/p7zip backend
    + Confirmation is now asked before adding, and renaming /
    moving files inside archives if items with same names
    already exists
    + Files / folders added to existing archive are now added to
    the directory that is currently being browsed
    + PeaZip now supports editing files in archives
  * "Open as archive" is now the standard action for opening
    unknown file types with PeaZip, consistently with other file
    archivers
  * Known archive types are automatically asked to be updated
    when temporary preview files are modified; Auto syncing can
    be turned off in options General > Auto update modified
    files in archives
  * Archives can manually be synced on request from context menu
    More > Force update modified files in archive; this allows
    to try to force to sync arbitrary archive types
  EXTRACTION and ARCHIVING
  * PeaZip shows estimated remaining time for archive / extract
    / test operations (for archive types supported through
    7z/p7zip backend)
* Fri Jun 14 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.8.1
  * Faster drag & drop extraction
  * Pre-testing of all archives for encryption before extraction
  * Improved progress bar
- Refreshed peazip-help_path.patch
* Sun May  5 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.8.0
  * Various fixes and improvements
* Sun Apr 14 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.7.2
  * More streamlined GUI for archiving and extraction, that can
    now be sent in background to system tray,
  * Smart extraction to new folder (to avoid extracting multiple
    items to destination, and for removing unnecessary levels of
    nesting),
  * Several improvements and fixes.
  * Multiple archiving and extraction tasks are now performed in
    a single instance, easier to hide, move or resize, providing
    progress bars for current task and for overall process.
  * A total of 188 file extensions can now be managed by PeaZip.
- Refreshed peazip-build_PIE.patch and peazip-help_path.patch
* Sun Mar 17 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.7.1
  * Various fixes
  * Drag and drop extraction results in hiding the main form,
    consistently to behavior from Extraction and Archiving screens
  * Extraction: "Smart new folder" option improves and replaces
    "Remove redundant directory" option if the new folder contains
    a single object (file or folder), content is copied outside and
    the extra folder is removed (removes extra folder layer and
    preserves original names of archived folders), if copying the
    content outside the new folder fails, the content is kept in
    the new folder smart extraction is meant to guarantee that a
    single item is extracted, to avoid flooding target directory of
    multiple unexpected items, and that no unneeded level of
    directory nesting is added
  * Improved GUI feedback during preliminary steps of archives
    conversion and "TAR before" procedures
  * Improved GUI feedback running option to delete original sources
  * Improved information shown about running archiving / extraction
    tasks
* Sun Feb 10 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.7.0
  * Several improvements and fixes
  * Multiple archiving and extraction tasks are now preformed
    in a single, more streamlined GUI instance, providing
    information and progress bars for current task and for
    overall process.
- Refreshed peazip-build_PIE.patch, peazip-help_path.patch and
  peazip-debuginfo.patch
* Tue Nov 27 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to fix build on aarch64:
  * peazip-fix_aarch64.patch
* Sun Oct 28 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.6.1
  * various improvements and fixes
  * it is now possible to force batch extraction of unsupported
    file types with PeaZip (or other custom executable), and to
    set a custom directory as working path.
* Mon Jun 11 2018 aloisio@gmx.com
- Fixed 7z requirement
* Sun May  6 2018 aloisio@gmx.com
- Update to version 6.6.0
  FILE MANAGER:
  * Added new fast function for hinting possible duplicates
    + Possible duplicates shows exactly same size, and same
    CRC32 calculated on sample(s) of file's data
    o For files up to 64 KB data it is sampled a 32 KB region
    at the beginning of the file
    o For files larger than 64 KB a second 32KB region is
    sampled after the half of the file
  * Added option to reset search history in search menu
  * Various fixes and improvements
  EXTRACTION and ARCHIVING:
  * New option "Try to edit non explicitly supported file types"
    in Options > Settings > Archive manager
    + off by default in order to protect from modification files
    outside known supported extensions
    + if on, allows to try to add/update and remove files form
    files not usually employed as archives, but structurally
    based on archive types such as Java jar, MS Office and OOo
    files, etc
- Added peazip-debuginfo.patch
- Switched build to gtk2 on account of startup crashes with Qt5
* Sun Feb 18 2018 aloisio@gmx.com
- Update to version 6.5.1
  * Updated Wolfgang Ehrhardt's libraries aes_2017-11-17,
    crc_hash_2018-01-01, fca_2017-11-17, serpent_2017-11-17,
    tf_2017-11-17, util_2018-01-01
  * Updates to compile with Lazarus 1.8.0 IDE (change to
    TShellTreeView Path, workaround for TImageList Clear)
  * Various fixes
- Dropped peazip-lazarus_1.8.0.patch (merged upstream)
* Fri Feb 16 2018 aloisio@gmx.com
- Added condition for runtime requirements
* Fri Feb 16 2018 aloisio@gmx.com
- Removed xorg-x11-devel build requirement
- Added peazip-help_path.patch to use the correct path for the
  pdf guide
* Sun Feb 11 2018 aloisio@gmx.com
- Added peazip-build_PIE.patch to produce position independent
  executables
* Thu Feb  1 2018 jengelh@inai.de
- Trim redundant wording from description.
- Run fdupes just over /usr.
* Wed Dec 27 2017 aloisio@gmx.com
- Update to version 6.5.0
  FILE MANAGER
  * Updated GUI and themes
  * Can now move and rename objects inside existing archives
    (7z/p7zip supported formats)
  EXTRACTION and ARCHIVING
  * Added option to force browsing of archives containing errors
    (default off)
  * Added option to show which options are volatile (context
    dependent) rather than persistent
  * Improved archive conversion
    + "Change password" switch (default off) asks to provide a new
    password to be applied to converted archive(s), otherwise
    current password (if any) will be applied - decompression
    stage test current password for each input archive, asking
    new password in case of error
  * Improved support for WIM format
    + in archiving and extraction interfaces, Advanced tab, were
    added options to operate including NT security information and
    NTFS Alternate Data Stream
    + file manager shows SHA-1 hash value for items in WIM archives
  * Scheduled deletion after archiving/extraction will not be
    performed if errors are detected
  CODE
  * Privacy directive is available as GUI option
    + 0 default, no password request
    + 1 application asks for password when starts, skippable
    + 2 application asks for password when starts, not skippable
    (password or keyfile must be provided)
  * Updated Wolfgang Ehrhardt's crypto library units
    + crc_hash_2017-06-04
    + fca_2016-05-01
    + util_2017-06-04
  * Various fixes and improvements
  version 6.4.1
  CODE
  * Added experimental privacy_mode directive (at current state
    can be changed only from configuration file, or hardcoded at
    compile time) meant to help users not forgetting to provide a
    password when working on sensitive data
    + 0 default, no password request
    + 1 application asks for password when stars, skippable
    + 2 application asks for password when starts, not skippable
    (password or keyfile must be provided)
  FILE MANAGER
  * Rightclicking on file manager's column header shows context
    menu for
    + customizing columns
    + applying on the fly checksum/hash, search for duplicates,
    and set algorithm for those two functions
    + save GUI content as tab-separated TXT file
  * Clicking the style icon on the right of the status bar shows
    menu of presets for file manager
    + Style icon now changes reflecting the style applied to the
    file manager
  * New "Navigation bar" entry in status bar menu show/hide side
    navigation bar
  * Some keyboard shortcuts were updated
    + Shift+Ctrl+N create new folder
    + Ctrl+N extract to new folder
    + Shift+Del quick delete (do not sent to recycle bin)
    + Ctrl+Del secure delete
    + Alt+Enter properties
  * Various improvements in archive browsing
  * Various improvements of UI usability with custom system colors
  EXTRACTION and ARCHIVING
  * During archive update only relevant options are shown,
    allowing to set password and to change action (add, update,
    freshen, sync)
  version 6.4.0
  BACKEND
  * pea 0.61
    + crc/hash marks duplicate files
    + shows number of copies found
    + to find duplicates, value of best checksum or hash algorithm
    is checked
  * (PeaUtils GUI) secure delete removes items from list if
    successfully erased
  CODE
  * Various fixes, visual updates and code cleanup
  FILE MANAGER
  * Added tabbed browsing
    + Tab bar is toggled from "Tab bar" entry available in from
    main menu > Organize, and in address bar and tab bar context
    menus
    + Tab bar is also shown clicking on "Open in a new tab" in
    context menu
    + Tabs can be added, deleted, moved, and resized
  * Added rename options (context menu, File manager > Rename) :
    prepend and append parent directory name
  * Improved rename dialog (F2)
  EXTRACTION and ARCHIVING
  * Added option to archive and extract using relative, full, or
    absolute paths (non-persistent value, in advanced options) for
    7z / p7zip supported archive formats
  * Improved archive conversion
    + If "Add each object to a separate archive" is checked
    (default), no extra root foder is added to the converted
    archive (supported for conversion toward all 7z/p7zip formats)
    + If the option is unchecked (consolidate multiple archives
    into one), it is added an extra folder with archive name to
    keep content separated
  version 6.3.1
  CODE
  * Various fixes
  FILE MANAGER
  * Minor visual updates
  version 6.3.0
  CODE
  * Improved DPI awareness
  * New command line directive "-peaziplanguage" to
    programmatically change application's localization
    + second parameter is the name of the localization file,
    proper localization directory "lang" is resolved by the program
    example: peazip.exe -peaziplanguage it.txt
    + please note if other instances of PeaZip are open, they will
    overwrite language in configuration when they close
  EXTRACTION and ARCHIVING
  * Added hamburger menu button in tabs bar to provide alternative
    access to archiving/extraction context menu
  * Improved archive creation screen
    + Added installer-mode sfx modules for 7z (advanced options
    tab)
    Replicated archiving action options in main options page
    (7z/p7zip supported types)
    Provided new update options: update only items already in
    archive (ignore extra items on disk), and synchronize archive
    with content on disk (remove items from archive if removed
    from disk)
  version 6.2.0
  BACKEND
  * Pea 0.58
  FILE MANAGER
  * Can now save list of items being browsed to TXT file,
    Navigation > Save as TXT
  * Reorganized keyboad shortcuts
    + Ctrl+O open selected item as archive
    + Ctrl+D toggle bookmarks panel
    + Ctrl+H toggle history panel
    + Ctrl+Alt+H toggle session history panel
  * Separated Add and Convert dropdown menus
  * Single "Extract" button for simplicity - quick extraction
    action/options are now all featured in Extract button dropdown
    menu
  * Browser, and archive/extraction screens, shows "filter" icon
    when advanced filters are set
  * Updated Ten teme
  EXTRACTION and ARCHIVING
  * Archiving and extraction screens shows cumulative progress bar
    when executing multiple operations
  * Improved command line options
    + added -ext2simple and -ext2simplefolder as "blanket"
    extraction command for all backend, first parameter specify
    output path;
    + password is asked interactively (GUI); "folder" variant
    extracts to new folder
  * Various fixes
- Dropped kde4 subpackage
- Added peazip-lazarus_1.8.0.patch
- Spec cleanup
* Tue Sep 13 2016 joerg.lorenzen@ki.tng.de
- update to version 6.1.1
  * BACKEND
  - (Linux) p7zip updated to 16.02.
  - Pea 0.56.
  * FILE MANAGER
  - Settings, archiving, and extraction screens made scrollable
    for better readability.
  - Various minor improvements and fixes.
  - File tools:
    CRC64 now is included in set of default algorithms.
    Default algorithm for the browser can now be set from
    context menu File manager > File Tools.
  * EXTRACTION and ARCHIVING
  - Password button moved on the right of output dialog for
    better visibility.
  - Some options were moved to Advanced options panels for
    archiving and extraction:
    "Use advanced filters" moved to Advanced options panel
    (archiving and extraction).
    "Enumerate folder content" and "Add timestamp to archive
    name", plus timestamp format option, moved to Advanced
    options panel (archiving).
  - Some options, previously volatile, are now saved to
    configuration:
    "Delete after archiving / extraction" option is now
    remembered, but user will always be warned by confirmation
    prompt before proceeding, in order to avoid accidental
    deletion.
    "Add timestamp to archive name" (archiving) is now
    remembered.
* Sat Aug 20 2016 joerg.lorenzen@ki.tng.de
- update to version 6.1.0
  * FILE MANAGER
  - Archive directory tree is shown in navigation sidebar while
    browsing an archive (above Bookmarks) and can be used for
    navigation or quick exploration of archive directory structure.
  - Added Expand/collapse archive tree toggle in quick history
    menu, allowing quick inspection of directory structure inside
    the archive.
  - In-archive breadcrumb improved, now showing list of
    directories from nodes dropdown menu, consistently with
    filesystem breadcrumb section.
  - File browser now shows .exe icons on Windows.
  - Can now set starting directory in Options > Settings >
    Advanced: last visited (default), computer's root, desktop,
    home, custom (user selected directory).
  - Fixed showing directories even if omitted in archive TOC.
  - Fixed sorting files without extensions.
  - Various fixes and improvements.
- version 6.0.3
  * BACKEND
  - Updated pea to 0.55 version fixing issues in reading header
    of PEA revision 1.0 files.
  - (Windows) Updated 7z backend to 16.02 version.
- version 6.0.2
  * BACKEND
  - (Windows) Updated 7z backend from 15.14 to 16.00 after Cisco
    Talos vulnerability disclosure
    http://blog.talosintel.com/2016/05/multiple-7-zip-vulnerabilities.html
  * FILE MANAGER
  - Can now correctly handle WinZip spanned files (.z01).
  - Fixed sorting for packed size.
  - Updated embedded translations.
* Wed May  4 2016 joerg.lorenzen@ki.tng.de
- update to version 6.0.1
  * BACKEND
  - Pea 0.54, implementing new PEA file format specifications
    1.1 version.
    Added support to SHA-3 256 and 512 bit hash.
    Added support to Twofish and Serpent (128 and 256 bit) based
    authenticated encryption in EAX mode.
    New pea binary can read PEA 1.0 file format.
    Previous pea binaries should be updated in order to read PEA
    1.1 files, and to support all new algorithms.
  - (Linux) Updated p7zip from 15.09 beta to 15.14
  * CODE
  - Updated following units from Wolfgang Ehrhardt's crypto and
    utilities library: aes_2015-09-14.zip, crc_hash_2015-09-14.zip,
    fca_2015-09-14.zip, util_2015-09-14.zip.
  - Created new EAX units using 128 and 256 bit Twofish (fcryptt,
    fctf256) and Serpent (fcrypts, fcsp256).
  * FILE MANAGER
  - Introduced support for SHA-3 256 and SHA-3 512 hash
    verification.
    SHA-3 hash is available both in file tools "Checksum/hash
    file(s)" and in browser (set in Options > File Tools).
  - Various fixes and improvements.
  * EXTRACTION and ARCHIVING
  - New "File" group in archiving/extraction context menu shows
    bookmarked and recent archive files, for quick adding to
    archiving/extraction layout.
* Thu Mar 17 2016 joerg.lorenzen@ki.tng.de
- update to version 6.0.0
  * BACKEND
  - Pea 0.53
    File management functions now accepts as input Unicode
    file/dir names.
    Report can now be displayed as table and as non tabbed
    clipboard text.
    PEA format now can handle Unicode file/dir names.
  - (Windows) 7z updated to 15.14
  * CODE
  - Recompiled with Lazarus 1.6.0/FPC3
    Native full support for Unicode filenames superseding
    PeaZip 5.8/5.9 internationalization mechanism based on
    internal UTF-8 encoding.
  - Major code cleanup
    Remove all now-unnecessary codepage-handling code.
    Removed all Windows 9x related code.
    Removed legacy code for pre-XP NT family systems, all
    features compatible with XP/2003 API will still work on
    those platforms.
    Transparence does no longer rely on Windows-only method and
    is available on any target OS.
  - Various fixes and improvements
  * FILE MANAGER
  - Improved navigation bar and menus
  - New themes "Ten", Win9x/2K inspired "Classic", and XP
    inspired "Experience"
    "Ten" theme is now default.
    All previous themes "Seven" and "Firecrystal" are still
    featured (select theme from Options > Setting > Themes).
  * EXTRACTION and ARCHIVING
  - Can now delete (recycle, quick, zero, secure) the open
    archive
  - Can now add directory to extraction; the path is recursively
    expanded to find archives to queue to extraction procedure
    Action is available from:
    Extract (button and app's context menu).
    Extract... entry in system context menu and SendTo menu.
  - ext2main from command line.
  - Can now test archive files inside directories
  - Support sorting by extension for solid 7z compression
    (default on)
  * WINDOWS INSTALLER
  - Convert existing archives now optionally available in context
    menu and SendTo menu
* Mon Dec 28 2015 joerg.lorenzen@ki.tng.de
- Create subpackage peazip-kf5 for openSUSE > 13.2 and Leap 42.1.
* Wed Dec 16 2015 joerg.lorenzen@ki.tng.de
- update to version 5.9.0
  * BACKEND
  - (Windows) 7z 15.12.
  - (Linux) p7zip 15.09:
    + PeaZip can now extract RAR5 files on Linux without resorting
    on separate UNRAR5 Plugin (still available as optional
    alternative extraction engine).
  - Pea 0.52.
  * CODE
  - Improved UTF-8 support in Windows.
  - Improved application startup and configuration process to make
    it more robust in case of random / system errors last good
    configuration is saved and automatically used as first restore
    attempt if configuration fails to load if configuration errors
    are detected anyway, volatile mode (using embedded configuration)
    is automatically activated.
  * FILE MANAGER
  - Improved secure delete, free space delete, and hashing / analysis
    functions:
    + Operations can be stopped by users.
    + More information and is shown while running the task and
    progress is more accurate, based on input size.
    + More information is provided by hashing / analysis tool:
  - For each subdirectory it is reported the content in files,
    folders and bytes (hinting possible duplicate directories).
  - First / last 32 bytes of files are shown for a quick preview
    (for hashing and content preview modes).
    + Report can be sorted for any column and can be exported to
    tabbed txt or to csv.
  - File hashing / analysis tools added in Test dropdown group
    in application tool bar.
  * EXTRACTION and ARCHIVING
  - Automatically removes redundant intermediate directory when
    extracting to new folder:
    + For better visibility option is also shown in main extraction
    form and in Extract dropdown group (in application tool bar).
  * LINUX INSTALLERS
  - Moved various backend (arc, lpaq, paq, zpaq, quad, and upx)
    into Optional Formats plugin, in order to reduce dependencies
    the main software package needs to satisfy to install (not
    needed by Portable versions).
* Thu Oct 22 2015 joerg.lorenzen@ki.tng.de
- update to version 5.8.1
  * (Windows) Updated to 7z 15.09.
  * Improved file rename.
  - Added option to mass-rename adding timestamp.
  - Easy rename clicking already selected item.
  - Rename dialog shows quick editing options: lowercase, uppercase,
    add timestamp.
  * Various aspect improvements.
  - More elements follows the system color scheme.
  - Improved aspect of Address and Search bar.
  - Added reset search button in Search Bar.
  * Improved UTF-8 support in Windows.
  - Can now correctly browse 7z-backend supported archives with
    UTF-8 characters in path/file name.
  - Can now drag and drop (from filesystem and from archives) to
    target with UTF-8 characters in path name.
  - Can now perform all delete operations (send to recycle bin,
    fast delete, zeroing, secure delete) on files/folders with
    UTF-8 characters in path/file name.
  - Can now copy and move files with UTF-8 characters in
    path/file name.
  - Cannot yet copy directories, or copy file over itself if
    UTF-8 characters are involved in the command.
- version 5.8.0
  * (Windows) Updated to 7z 15.07, adding support to QUEMU, VirtualBox,
    and VMWare virtual machine's disk image formats.
  * "Free Software compliance" directive (Options > Advanced,
    previosly named LIBRE_DIRECTIVE) can be either set in
    configuration or hardcoded at compile time (HLIBRE_DIR const).
  - 1 allow only use of Free Software components 2 allow only use
    of Free Software components and open archive formats (not
    encumbered by patents for read nor for write).
  * Various fixes.
  * (Windows) Improved UTF-8 support.
  - PeaZip can now create and extract archives with UTF-8 filenames,
    both from application and from system context menu.
  - Browsing archives with UTF-8 filenames is possible but it
    is still under development (warning icon is displayed).
  - Console tab shows if action can be exported as script
    ANSI-safe (can run on legacy systems regardless the encoding),
    codepage-safe (can run on legacy systems with same codepage
    of original device), or if requires full UTF-8 environment
    (system, command/script interpreter).
  - Some file management functions now supports UTF-8 filenames.
  * Improved password management.
  - If password is set to not being kept for the entire session,
    it is cleared after every operation (archiving, extraction,
    browsing the filesystem) except while browsing archive file,
    as password may be needed for listing the archive content.
  * Number of files/folders selected for cut/copy is displayed in
    Clipboard panel and in status bar's hint.
* Wed Sep 30 2015 joerg.lorenzen@ki.tng.de
- update to version 5.7.2
  * Updated to 7z 15.06 (Windows).
  - Users can chose to extract RAR5 files alternatively using
    7z (default) or RarLab's unrar plugin, setting "7z/p7zip UNRAR5"
    switch in Options > General.
  * Improved file/archive browser sorting.
  * Fixed bug not removing PeaZip group entry on uninstall
    (affected 32 bit version, W7+ only).
- version 5.7.1
  * Breadcrumb can display in-archive paths for quick browsing.
  * Added option to customize timestamp style (Options > Settings >
    Archive Manager).
  * Added option to split self extracting archives in 7z format
  - Split sfx archives will result in a small extraction executable,
    and n volumes of desired size.
  - Spanning sfx archive allows to prevent the resulting archive
    being larger of the maximum executable size allowed for the
    target OS.
  - To extract a split sfx archive, place extraction executable
    and all volumes in the same directory.
    + Extraction executable will start pre-set extraction
    procedure without need of external software.
    + Alternatively, volume with .001 extension can be opened
    with an external archiver to browse/extract the entire
    archive.
  * Updated file split pre-sets.
  - Added 25 GB Blu-Ray pre-set size.
  * Custom pre-set size modified in 100 MB.
  * Assumed lower, more fail-safe pre-set maximum size values for
    disk formats, to improve compatibility with most supports.
  - Updated to Innosetup 5.5.6, switched to unicode installer,
    improved Windows 10 / 8.1 support.
* Thu Jul 30 2015 joerg.lorenzen@ki.tng.de
- update to version 5.7.0
  * (Linux) Added read only support (list, test, extract) to RAR5
    format through RarLab-based unrar-nonfree; due the non-OSI
    compatible unrar restriction the software is available as
    separate plugin on Add-Ons page of PeaZip website.
  * (Linux) Updated p7zip backend to 9.38.1 beta.
  * (Windows) Updated 7z backend to 15.05 beta.
  * Updated IDE to Lazarus 1.4.0.
  * Updated libraries: crc_hash_2014-08-25, util_2015-05-04.
  * Various fixes and updates.
  * Improved management of plug-ins:
  - In About screen, missing and installed plugin are repported,
    and it is shown a link for checking plugin and addon online.
  - When opening an archive format (ACE, RARv5) requiring a plugin,
    user is informed if the plugin is missing, and how to download it.
  - Information popup is limited to one per plugin type per session.
* Mon Jun 15 2015 joerg.lorenzen@ki.tng.de
- update to version 5.6.1
  * Added read only support (list, test, extract) to RAR5 format
    through RarLab's unrar.
    Currently the plugin is available only for Windows or Wine/ReactOS,
    Linux version will be analyzed and tested for future updates.
  * Due the non-OSI compatible unrar restriction (even if the software
    provides sources and is royalty-free) the software is available as
    separate plugin on Add-Ons page.
  * Due the different syntax between RarLab's unrar and 7z/p7zip's unrar,
    following differences apply when handling RAR5 format:
  - Recursivity with advanced filters is always enabled.
  - Renaming options always rename the file being extracted.
  * Added LIBRE_DIRECTIVE option to disallow any call to software
    which is non-free under OSI definition:
  - If set to 0 (permissive) PeaZip will use all available backend,
    both free-as-in-freedom and royalty-free.
  - If set to 1 (flexible) PeaZip will disallow any call to
    royalty-free but non free-as-in-freedom backend,
    currently: unace and unrar binaries.
  - If set to 2 (strict) PeaZip will disallow calls even in case
    of dubious status, currently apply to unrar functions in
    7z/p7zip due to non-reversibility clause.
  * Various minor fixes.
* Sun Apr 26 2015 joerg.lorenzen@ki.tng.de
- update to version 5.6.0
  * Added full read/write support to BCM file compressor.
  * Updated to ZPAQ 7.05.
  * Improved support, now it is possible to add content to existing
    zpaq archive.
  * Archive selection dialogs improved with custom filters for
    common archive types.
  * File submenu improved with direct links to update, convert and
    extract archives.
  * New hotkeys: Shift+F5 add selected to archive, Ctrl+F5 extract
    selected, Alt+F5 extract archive (opens archive selection dialog).
  * Tray icon menu improved with direct links to update, convert
    and extract archives.
  * Improved dialog for setting custom applications and scripts,
    moved in Options.
  * Fixed custom applications not found in some cases on Win64 systems.
  * Both 32 and 64 bit program paths are scanned, 64 bit version
    have the priority.
  * Improved Help and About screens.
  * F4 now shows navigation menu, jump to archive/computer root
    moved to Ctrl+Shift+F4.
  * Alt+0 toggle application's tool bar.
  * Various improvements and fixes.
  * PeaExtractor 1.1 code merged in pealauncher component.
  * Created default location to save archive layout files.
  * Non-verbose mode for archive conversion (default option).
  * 182 file extensions supported.
  * Added full read/write support to BCM compression format.
* Tue Jan 20 2015 joerg.lorenzen@ki.tng.de
- update to version 5.5.3
  * Updated to 7z 9.38 beta back-end, with LZMA2 replacing LZMA
    as default compression algorithm for .7z format.
  * Improved file browser's address breadcrumb with clickable icons
    for each node, showing directory list for each level.
  * Improved application's menus.
  * 181 file extensions are now supported.
  * Added peazip_help.pdf to doc.
* Sat Dec 27 2014 joerg.lorenzen@ki.tng.de
- update to version 5.5.2
  * Updated to 7z 9.35 beta back-end for handling mainstream archive
    formats, with LZMA2 replacing LZMA as default compression
    algorithm for .7z format.
  * Added support for more anti-virus / anti-malware for on demand
    scanning of files inside archives: Avast Pro / Internet Security,
    ClamWin, Comodo Cleaning Essentials, ESET NOD32 / Smart Security.
  * 181 file extensions are now supported
* Tue Dec  9 2014 joerg.lorenzen@ki.tng.de
- update to version 5.5.1
  * File formats that can be handled by PeaZip are highlighted by
    a character in Information column:
    '+' known archive type, open with double click
    (i.e. RAR, TAR, ZIP, ZIPX...)
    '.' known file type usually not handled as archive, open
    with "Open as archive" (i.e. EXE, DLL, MS Office files)
  * New "Update only" mode for Windows installer, update
    application's files and keeps unchanged the system settings
    (file associations, context menu, send to menu)
  * 181 file extensions are now supported
* Mon Oct 20 2014 joerg.lorenzen@ki.tng.de
- update to version 5.5.0
  * PeaZip 5.5.0 introduces option to halt system after task completion,
    and to remove single intermediate root directories on "Extract to new folder".
  * File manager features new batch file rename functions, and advanced selection filters.
  * Image manager now convert graphic files also to TIFF, PPM, and XPM format,
    fit images to 4K/8K screen resolutions, and features compression to
    50/75/90 JPEG quality pre-sets.
* Wed Sep 10 2014 aloisio@gmx.com
- Corrected a German string appearing in every locale
- Added Italian strings for the KDE actions menu
* Wed Aug 13 2014 joerg.lorenzen@ki.tng.de
- update to version 5.4.1
  * Release 5.4.1 brings a major refresh in GUI design, in order to
  speed up user's work flow, and make easier to discover useful functions
  (as new quick archiving/compression pre-sets) and most relevant information.
  It is now possible to automatically remove original files after archival,
  and to remove original archives after extraction, with customizable deletion
  procedure (recycle, quick / zero / secure delete), that can also be added to
  exported scripts / scheduled tasks.
  In extraction and compression screens it was made simpler to re-use last
  output path, and to navigate recent folders to drag and drop files from
  system to application.
  Alongside many other improvements and updates, ZPAQ backend was updated to 6.54.
* Tue Jul  8 2014 joerg.lorenzen@ki.tng.de
- update to version 5.4.0
  * Release 5.4.0 brings a major refresh in GUI design, in order to
    speed up user's work flow, and make easier to discover useful functions
    (as new quick archiving/compression pre-sets) and most relevant information.
    It is now possible to automatically remove original files after archival,
    and to remove original archives after extraction, with customizable deletion
    procedure (recycle, quick / zero / secure delete), that can also be added to
    exported scripts / scheduled tasks.
    Alongside many other improvements and updates, ZPAQ backend was updated to 6.54.
* Mon May  5 2014 joerg.lorenzen@ki.tng.de
- update to version 5.3.1
  * PeaZip 5.3.1 is a maintenance update with various fixes, and updated
    translations of application and system's context menu text.
    Release 5 brings a major code and design cleanup: UAC integration is improved,
    file and archive browsing is easier and more customizable, and relevant information
    is more visible.
    Most important file and archive management functions are more accessible,
    adding files to archive is faster, inclusion/exclusion filters are more efficient,
    and pre-set compression profiles allows single click switching between most common
    compression tasks (i.e. best/fast compression, protect with password, span archive...).
    New features includes Schedule tab in Archive/Convert and Extract interfaces
    (integrated with Windows Vista/7/8/8.1 Task Scheduler); secure deletion of free space,
    and zero deletion mode (overwriting files/free space with all 0);
    localized Windows context menu; new standalone GUI for basic archive extraction
    and file management tasks.
* Wed Apr 16 2014 joerg.lorenzen@ki.tng.de
- update to version 5.3.0
  * PeaZip 5.3.0 introduces improved navigation bar, localized Windows context menu,
    improves inclusion/exclusion filters, adds a synthetic archive information function,
    and introduces pre-set compression profiles for single-click switching between most
    common compression task, i.e. best compression, fast compression, protect with password,
    create self extracting archive, keep output under a specified size for mail attachment, etc.
    Release 5 brings a major code and design cleanup: adding files to archive is faster,
    UAC integration is improved, file and archive browsing is easier and more customizable,
    most important file and archive management functions are more accessible,
    and relevant information is more visible.
    New features includes: Schedule tab in Archive/Convert and Extract interfaces
    (integrated with Windows Vista/7/8/8.1 Task Scheduler), new secure deletion of free space,
    and zero deletion mode (overwriting files/free space with all 0), new standalone GUI for
    basic archive extraction (Tools > PeaExtractor) and for basic file management tasks (Tools > PeaUtils).
* Wed Feb 26 2014 joerg.lorenzen@ki.tng.de
- update to version 5.2.2
  * PeaZip 5.2.2 improves help system, and introduces standalone minimal GUI (Tools > PeaExtractor and Pea Utils)
    to be used when a narrower-focused interface is desired for simple archive/file management tasks.
    Release 5 brought a major code and design cleanup: adding files to archive is faster, file
    and archive browsing is easier and more customizable, most important file and archive management functions
    are more accessible, and relevant information is more visible.
    Schedule tab in Archive/Convert and Extract interfaces, integrated with system's Task Scheduler (Windows Vista/7/8/8.1),
    helps users creating scheduled backup/restore scripts.
    Secure deletion of free space completes program's features to securely manage data life cycle.
    Zero deletion mode overwriting files / free space content with all 0 optimize compressibility of backup
    and virtual machine's disk images.
    178 file extensions are now supported.
* Fri Dec 27 2013 joerg.lorenzen@ki.tng.de
- update to version 5.2.1
  * PeaZip 5.2.1 improves secure files / free space deletion, updates translations
    and links to online resources.
    Release 5 brought a major code and design cleanup: adding files to archive is faster,
    file and archive browsing is easier and more customizable, most important file and
    archive management functions are more accessible, and relevant information is more visible.
    Schedule tab in Archive/Convert and Extract interfaces, integrated with system's
    Task Scheduler (Windows Vista/7/8/8.1), helps users creating scheduled backup/restore scripts.
    Secure deletion of free space completes program's features to securely manage data life cycle.
    Zero deletion mode overwriting files / free space content with all 0 optimize compressibility
    of backup and virtual machine's disk images.
* Sun Dec 15 2013 joerg.lorenzen@ki.tng.de
- fixed wrong BuildRequires from qt4Pas-devel to qt4pas-devel
* Mon Nov 25 2013 joerg.lorenzen@ki.tng.de
- update to version 5.2.0
  * PeaZip 5.2.0 introduces secure deletion of free space, and zero deletion mode overwriting file
    or free space content with all 0 in order to optimize compressibility of backup disk images
    and virtual machine disks. This release also brings improvements in UAC integration,
    makes help file available locally, and adds capability to archive/extract at once multiple files
    from different paths each to original location.
* Sun Oct  6 2013 joerg.lorenzen@ki.tng.de
- update to version 5.1.1
  * 5.1.1 update brings various fixes to improve user experience, and updates translations.
    175 file extensions are supported.
* Sun Sep  1 2013 joerg.lorenzen@ki.tng.de
- update to version 5.1.0
  * 5.1.0 update brings various fixes, improves Windows installer,
    and adds a Schedule tab to Archive/Convert and Extract interfaces,
    integrated with system's Task Scheduler (Windows Vista/7/8/8.1),
    for help users creating scheduled backup/restore scripts from a single place.
    175 file extensions are supported, PeaZip now handles .ipsw iOS devices firmware packages.
* Sun Jul 21 2013 joerg.lorenzen@ki.tng.de
- update to version 5.0.1
  * 5.0.1 update brings various fixes, updates embedded translations,
    improves Windows installer, and is compiled with new Lazarus 1.0.10.
* Mon Jul  1 2013 joerg.lorenzen@ki.tng.de
- Initial package, version 5.0
